# This is a dedicated spec file for building jglobus for EPEL 5 and 6
# Instead of using maven - which is not available on RHEL/EPEL - ant
# is used for building. The ant build files were created using the
# maven ant plugin

%if "%{rhel}" == "5"
%global tomcat tomcat5
%global tomcatlib tomcat5-server-lib
%global tomcatutil %{tomcat}/tomcat-util
%else
%global tomcat tomcat6
%global tomcatlib tomcat6-lib
%endif

Name:		jglobus
Version:	2.0.6
Release:	2%{?dist}
Summary:	Globus Java client libraries

#		Everything is Apache 2.0 except for one file that is MIT:
#		ssl-proxies/src/main/java/org/globus/tools/GridCertRequest.java
License:	ASL 2.0 and MIT
Group:		Development/Libraries
URL:		http://github.com/%{name}/
Source0:	http://github.com/%{name}/JGlobus/archive/JGlobus-%{version}.tar.gz
#		Build with ant on old distributions
Source1:	%{name}-ant-%{version}.tar.gz
#		Fixes from Bartek Palak (see pull request in github)
Patch0:		jglobus-final-static.patch
Patch1:		jglobus-semi.patch
Patch2:		jglobus-synch-disconnect.patch
Patch3:		jglobus-errors.patch
Patch4:		jglobus-impl-clonable.patch
Patch5:		jglobus-dont-hide-super.patch
#		Fix javadoc warnings
Patch6:		jglobus-doc.patch
#		Name parent parent
Patch7:		jglobus-parent.patch

BuildArch:	noarch
#		There is no bouncycastle for ppc in EPEL5 and ppc64 in EPEL6
ExcludeArch:	ppc ppc64
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:	jpackage-utils
BuildRequires:	java-devel
BuildRequires:	dos2unix
BuildRequires:	ant

BuildRequires:	jakarta-commons-codec
BuildRequires:	jakarta-commons-io
BuildRequires:	jakarta-commons-logging
BuildRequires:	bouncycastle
BuildRequires:	log4j
BuildRequires:	%{tomcatlib}
BuildRequires:	axis
BuildRequires:	servlet

%description
%{name} is a collection of Java client libraries for Globus Toolkit security,
GRAM, GridFTP and MyProxy.

%package ssl-proxies
Summary:	Globus Java - SSL and proxy certificate support
License:	ASL 2.0 and MIT
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	jakarta-commons-codec
Requires:	jakarta-commons-io
Requires:	jakarta-commons-logging
Requires:	bouncycastle
Requires:	log4j

%description ssl-proxies
Globus Java library with SSL and proxy certificate support

%package jsse
Summary:	Globus Java - SSL support
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-ssl-proxies = %{version}-%{release}

%description jsse
Globus Java library with SSL support

%package gss
Summary:	Globus Java - GSS-API implementation for SSL with proxies
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-jsse = %{version}-%{release}

%description gss
Globus Java GSS-API implementation for SSL with proxies

%package gram
Summary:	Globus Java - Grid Resource Allocation and Management (GRAM)
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}

%description gram
Globus Java library with GRAM support

%package gridftp
Summary:	Globus Java - GridFTP
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}

%description gridftp
Globus Java library with GridFTP support

%package ssl-proxies-tomcat
Summary:	Globus Java - SSL and proxy certificate support for Tomcat
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-jsse = %{version}-%{release}
Requires:	%{tomcatlib}

%description ssl-proxies-tomcat
Globus Java library with SSL and proxy certificate support for Tomcat

%package io
Summary:	Globus Java - IO
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gram = %{version}-%{release}
Requires:	%{name}-gridftp = %{version}-%{release}

%description io
Globus Java library with IO utilities

%package myproxy
Summary:	Globus Java - MyProxy
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}

%description myproxy
Globus Java library with MyProxy support

%package axisg
Summary:	Globus Java - Apache AXIS support
License:	ASL 2.0
Group:		Development/Libraries
Requires:	jpackage-utils
Requires:	java
Requires:	%{name}-gss = %{version}-%{release}
Requires:	axis
Requires:	servlet

%description axisg
Globus Java library with Apache AXIS support

%package javadoc
Summary:	Javadocs for %{name}
License:	ASL 2.0 and MIT
Group:		Documentation
Requires:	jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -a 1 -n JGlobus-JGlobus-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%if "%{rhel}" == "5"
patch -p1 < ssl-proxies-tomcat/src/main/patches/jglobus-tomcat5.patch
%endif

dos2unix axis/src/main/java/org/globus/axis/example/README.txt
chmod 644 axis/src/main/java/org/globus/axis/example/README.txt

# Move test classes to test directory
mkdir -p gram/src/test/java/org/globus/gram/util
mv gram/src/main/java/org/globus/gram/Gram15Test.java \
   gram/src/test/java/org/globus/gram/Gram15Test.java
mv gram/src/main/java/org/globus/gram/GramTest.java \
   gram/src/test/java/org/globus/gram/GramTest.java
mv gram/src/main/java/org/globus/gram/MultiUserGramTest.java \
   gram/src/test/java/org/globus/gram/MultiUserGramTest.java
mv gram/src/main/java/org/globus/gram/util/TestUtil.java \
   gram/src/test/java/org/globus/gram/util/TestUtil.java

# Move gram tests using io classes to io directory
mkdir -p io/src/test/java/org/globus/gram/tests
mkdir -p io/src/test/java/org/globus/gram/util
mkdir -p io/src/test/resources
mv gram/src/test/java/org/globus/gram/Gram15Test.java \
   io/src/test/java/org/globus/gram/Gram15Test.java
mv gram/src/test/java/org/globus/gram/tests/GramTest.java \
   io/src/test/java/org/globus/gram/tests/GramTest.java
mv gram/src/test/java/org/globus/gram/tests/test.sh \
   io/src/test/java/org/globus/gram/tests/test.sh
mv gram/src/test/java/org/globus/gram/util/TestUtil.java \
   io/src/test/java/org/globus/gram/util/TestUtil.java
mv gram/src/test/resources/test.properties \
   io/src/test/resources/test.properties

# Remove code duplication
mkdir -p gss/src/test/java/org/globus/net/test
mv gram/src/test/java/org/globus/net/test/GSIHttpURLConnectionTest.java \
   gss/src/test/java/org/globus/net/test/GSIHttpURLConnectionTest.java
rm gss/src/test/java/org/globus/net/GSIHttpURLConnectionTest.java
rm -rf gram/src/main/java/org/globus/net      # also in gss
rm -rf gram/src/main/java/org/globus/io/gass  # also in io

# Move test.properties files to resources directories
mkdir -p gridftp/src/test/resources/org/globus/ftp/test
mkdir -p myproxy/src/test/resources/org/globus/myproxy/test
rm gridftp/src/test/java/org/globus/ftp/test/test1.properties
rm gridftp/src/test/java/test.properties
mv gridftp/src/test/java/org/globus/ftp/test/test.properties \
   gridftp/src/test/resources/org/globus/ftp/test/test.properties
mv gridftp/src/test/java/org/globus/ftp/test/test.properties.in \
   gridftp/src/test/resources/org/globus/ftp/test/test.properties.in
mv myproxy/src/test/java/org/globus/myproxy/test/test.properties \
   myproxy/src/test/resources/org/globus/myproxy/test/test.properties

%build
# Many tests requires network connections and a valid proxy certificate
export CLASSPATH=$(build-classpath bcprov log4j commons-codec commons-httpclient commons-io commons-logging %{tomcat}/catalina %{tomcat}/tomcat-coyote %{?tomcatutil} axis/axis axis/jaxrpc servlet):ssl-proxies/target/ssl-proxies-%{version}.jar:jsse/target/jsse-%{version}.jar:gss/target/gss-%{version}.jar:gram/target/gram-%{version}.jar:gridftp/target/gridftp-%{version}.jar
ant -Dmaven.test.skip=true package javadoc

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_javadir}/%{name}
install -p -m 644 ssl-proxies/target/ssl-proxies-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/ssl-proxies.jar
install -p -m 644 jsse/target/jsse-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/jsse.jar
install -p -m 644 gss/target/gss-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/gss.jar
install -p -m 644 gram/target/gram-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/gram.jar
install -p -m 644 gridftp/target/gridftp-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/gridftp.jar
install -p -m 644 ssl-proxies-tomcat/target/ssl-proxies-tomcat-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/ssl-proxies-tomcat.jar
install -p -m 644 io/target/io-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/io.jar
install -p -m 644 myproxy/target/myproxy-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/myproxy.jar
install -p -m 644 axis/target/axisg-%{version}.jar \
    %{buildroot}%{_javadir}/%{name}/axisg.jar

mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr ssl-proxies/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/ssl-proxies
cp -pr jsse/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/jsse
cp -pr gss/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gss
cp -pr gram/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gram
cp -pr gridftp/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/gridftp
cp -pr ssl-proxies-tomcat/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/ssl-proxies-tomcat
cp -pr io/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/io
cp -pr myproxy/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/myproxy
cp -pr axis/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/axisg

%clean
rm -rf %{buildroot}

%files ssl-proxies
%dir %{_javadir}/%{name}
%{_javadir}/%{name}/ssl-proxies.jar
%doc LICENSE README.textile

%files jsse
%{_javadir}/%{name}/jsse.jar

%files gss
%{_javadir}/%{name}/gss.jar

%files gram
%{_javadir}/%{name}/gram.jar

%files gridftp
%{_javadir}/%{name}/gridftp.jar

%files ssl-proxies-tomcat
%{_javadir}/%{name}/ssl-proxies-tomcat.jar

%files io
%{_javadir}/%{name}/io.jar

%files myproxy
%{_javadir}/%{name}/myproxy.jar

%files axisg
%{_javadir}/%{name}/axisg.jar
%doc axis/src/main/java/org/globus/axis/example/README.txt

%files javadoc
%doc %{_javadocdir}/%{name}

%changelog
* Mon Nov 25 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.6-2
- Fix source URL

* Wed Aug 14 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.6-1
- 2.0.6 final release

* Tue Mar 26 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.5-1
- 2.0.5 final release

* Tue Jan 29 2013 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.5-0.1.rc2
- 2.0.5 release candidate 2
- New jglobus-myproxy package
- New jglobus-axisg package

* Sat Oct 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-9.20121013git597e3ac
- Git snapshot

* Wed Oct 10 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-8.20121010git8eefd68
- Git snapshot
- Drop patches applied upstream

* Wed Oct 10 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-7.20121010git5286c6b
- Git snapshot
- Drop patches applied upstream

* Thu Sep 27 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-6
- Drop spring framework dependency (based on pull request in github)
- Allows building on EPEL

* Mon Aug 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-5
- Build the tomcat module

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri May 04 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-3
- Adapt to changes in automatic maven rpm dependency generation

* Mon Apr 23 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-2
- Add MIT license tag

* Fri Apr 13 2012 Mattias Ellert <mattias.ellert@fysast.uu.se> - 2.0.4-1
- First packaging
